<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":                                    $messaggio = "Der Nachname wird ge&auml;ndert von"; break;
case "a":                                                                $messaggio = "zu"; break;
case "Il nome verrà cambiato da":                                       $messaggio = "Der Name wird ge&auml;ndert von"; break;
case "Il sesso verrà cambiato a":                                       $messaggio = "Das Geschlecht wird ge&auml;ndert zu "; break;
case "La data di nascita  verrà cambiata da":                           $messaggio = "Der Geburtstag wird ge&auml;ndert von"; break;
case "Il telefono verrà cambiato da":                                   $messaggio = "Die Telefonnummer wird ge&auml;ndert von"; break;
case "La via  verrà cambiata da":                                       $messaggio = "Die Stra&szlig;e wird ge&auml;ndert von"; break;
case "Il numero civico verrà cambiato da":                              $messaggio = "Die Hausnummer wird ge&auml;ndert von"; break;
case "La città di residenza verrà cambiata da":                        $messaggio = "Die Stadt wird ge&auml;ndert von"; break;
case "La nazione di residenza verrà cambiata da":                       $messaggio = "Das Aufenthaltsland wird ge&auml;ndert von "; break;
case "Il CAP verrà cambiato da":                                        $messaggio = "Die Postleitzahl wird ge&auml;ndert von"; break;
case "Il fax verrà cambiato da":                                        $messaggio = "Die Faxnummer wird ge&auml;ndert von"; break;
case "L' email verrà cambiata da":                                      $messaggio = "Die Email wird ge&auml;ndert von"; break;
case "Il 2° telefono verrà cambiato da":                               $messaggio = "Die Handynummer wird ge&auml;ndert von"; break;
case "Il 3° telefono verrà cambiato da":                               $messaggio = "Die 2. Telefonnummer wird ge&auml;ndert von"; break;
case "Il <b>commento</b> verrà cambiato":                               $messaggio = "Der Kommentar wird ge&auml;ndert"; break;
case "Il <b>nome</b> verrà cancellato":                                 $messaggio = "Der <b>Name</b> wird gel&ouml;scht"; break;
case "La <b>data di nascita</b> verrà cancellata":                      $messaggio = "Der <b>Geburtstag</b> wird gel&ouml;scht"; break;
case "Il <b>telefono</b> verrà cancellato":                             $messaggio = "Die <b>Telefonnummer</b> wird gel&ouml;scht"; break;
case "La <b>via</b> verrà cancellata":                                  $messaggio = "Die <b>Stra&szlig;e</b> wird gel&ouml;scht"; break;
case "Il <b>n° civico</b> verrà cancellato":                           $messaggio = "Die <b>Hausnummer</b> wird gel&ouml;scht"; break;
case "La <b>città di residenza</b> verrà cancellata":                  $messaggio = "Der<b>Wohnort</b> wird gel&ouml;scht"; break;
case "La <b>nazione di residenza</b> verrà cancellata":                 $messaggio = "Das<b>Aufenthaltsland</b> wird gel&ouml;scht"; break;
case "Il <b>CAP</b> verrà cancellato":                                  $messaggio = "Die <b>Postleitzahl</b> wird gel&ouml;scht"; break;
case "Il <b>fax</b> verrà cancellato":                                  $messaggio = "Die <b>Hausnummer</b> wird gel&ouml;scht"; break;
case "L' <b>email</b> verrà cancellata":                                $messaggio = "Die <b>Email</b> wird gel&ouml;scht"; break;
case "Il <b>2° telefono</b> verrà cancellato":                         $messaggio = "Die <b>Handynummer</b> wird gel&ouml;scht"; break;
case "Il <b>3° telefono</b> verrà cancellato":                         $messaggio = "Die <b>2. Telefonnummer</b> wird gel&ouml;scht"; break;
case "Continua":                                                         $messaggio = "Weiter"; break;
case "Il cliente":                                                       $messaggio = "Gast"; break;
case "è stato modificato":                                              $messaggio = "wurde ge&auml;ndert"; break;
case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
case "Modifica i dati del cliente":                                      $messaggio = "Gastdaten sichern"; break;
case "Cognome":                                                          $messaggio = "Nachname"; break;
case "cambia in":                                                        $messaggio = ""; break;      // ndern zu oder neu case "Nome":                                                             $messaggio = "Vorname"; break;
case "Nome":                                                             $messaggio = "Vorname"; break;
case "cancella":                                                         $messaggio = "l&ouml;schen"; break;
case "Sesso":                                                            $messaggio = "Geschlecht"; break;
case "Data di nascita":                                                  $messaggio = "Geburtstag"; break;
case "Telefono":                                                         $messaggio = "Telefon"; break;
case "Via":                                                              $messaggio = "Stra&szlig;e"; break;
case "Piazza":                                                           $messaggio = "Platz"; break;
case "Viale":                                                            $messaggio = "Allee"; break;
case "Piazzale":                                                         $messaggio = "Weg"; break;
case "Vicolo":                                                           $messaggio = "Stra&szlig;e"; break;
case "Numero civico":                                                    $messaggio = "Nr."; break;
case "Città di residenza":                                              $messaggio = "Wohnort"; break;
case "Nazione di residenza":                                             $messaggio = "Aufenthaltsland"; break;
case "CAP":                                                              $messaggio = "Postleitzahl"; break;
case "Fax":                                                              $messaggio = "Fax"; break;
case "Email":                                                            $messaggio = "E-Mail"; break;
case "2° telefono":                                                     $messaggio = "Mobiltelefon"; break;
case "3° telefono":                                                     $messaggio = "2. Telefon"; break;
case "Commento":                                                         $messaggio = "Kommentar"; break;
case "documento di tipo":                                                $messaggio = "Dokument"; break;
case "visualizza":                                                       $messaggio = "erstellen"; break;
case "visualizza il documento":                                          $messaggio = "Dokument ansehen"; break;
case "Prenotazioni del cliente":                                         $messaggio = "Buchungen des Gastes"; break;
case "nel":                                                              $messaggio = "in"; break;
case "Cognome_del_cliente":                                              $messaggio = "Nachname"; break;
case "Data_iniziale":                                                    $messaggio = "Anfangsdatum"; break;
case "Data_finale":                                                      $messaggio = "Enddatum"; break;
case "Tariffa_completa":                                                 $messaggio = "Gesamtpreis"; break;
case "Caparra":                                                          $messaggio = "Anzahlung"; break;
case "Pagato":                                                           $messaggio = "Bezahlt"; break;
case "Commento":                                                         $messaggio = "Kommentar"; break;
case "TOTALE":                                                           $messaggio = "Gesamt"; break;
case "Pers":                                                             $messaggio = "Pers."; break;
case "Inserito da":                                                      $messaggio = "Eingegeben von"; break;
case "Si considererà l'utente":                                         $messaggio = "Benutzer"; break;
case "come colui che ha inserito il cliente":                            $messaggio = "wird eingetragen als der der den Gast eingetragen hat"; break;
case "Cliente cancellato":                                               $messaggio = "Gast gel&ouml;scht"; break;
case "Cancella il cliente":                                              $messaggio = "Gast l&ouml;schen"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":        $messaggio = "Dieser Gast kann nicht gel&ouml;scht werden, da f&uuml;r ihn eine Reservierung vorliegt."; break;
case "NO":                                                               $messaggio = "NEIN"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":        $messaggio = "Wollen Sie den Datensatz wirklich <div style=\"display: inline; color: red;\">l&ouml;schen</div>"; break;
case "SI":                                                               $messaggio = "JA"; break;
case "Reg./Prov. di residenza":                                          $messaggio = "Bundesland"; break;
case "Documento":                                                        $messaggio = "Ausweisdokument"; break;
case "Scadenza documento":                                               $messaggio = "g&uuml;tig bis"; break;
case "Il documento verrà cambiato da":                                  $messaggio = "Das Dokument wurde ge&auml;ndert von"; break;
case "La data di scadenza del documento  verrà cambiata da":            $messaggio = "Das Ablaufdatum des Ausweisdokuments wird ge&auml;ndert von "; break;
case "La <b>regione di residenza</b> verrà cancellata":                 $messaggio = "Die <b>Wohnsitzregion</b> wird gel&ouml;scht"; break;
case "Il <b>documento</b> verrà cancellato":                            $messaggio = "Das <b>Ausweisdokument</b> wird gel&ouml;scht"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":       $messaggio = "Das <b>Ablaufdatum des Ausweisdokuments</b> wird gel&ouml;scht"; break;
case "Cittadinanza":                                                     $messaggio = "Nationalit&auml;t"; break;
case "Nazione di nascita":                                               $messaggio = "Geburtsland"; break;
case "Reg./Prov. di nascita":                                            $messaggio = "Geburtsregion"; break;
case "Città di nascita":                                                $messaggio = "Geburtsort"; break;
case "Città di rilascio":                                               $messaggio = "Ausstellende Stadt"; break;
case "Reg./Prov. di rilascio":                                           $messaggio = "Ausstellende Region"; break;
case "Nazione di rilascio":                                              $messaggio = "Ausstellendes Land"; break;
case "La cittadinanza verrà cambiata da":                               $messaggio = "Die Nationalit&ouml;t wird ge&auml;ndert von"; break;
case "La nazione di nascita verrà cambiata da":                         $messaggio = "Das Geburtsland wird ge&auml;ndert von"; break;
case "La regione di nascita verrà cambiata da":                         $messaggio = "Die Geburtsregion wird ge&auml;ndert von"; break;
case "La città di nascita verrà cambiata da":                          $messaggio = "Die Geburtsstadt wird ge&auml;ndert von"; break;
case "La città di rilascio del documento verrà cambiata da":           $messaggio = "Die ausstellende Stadt wird ge&auml;ndert von"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":$messaggio = "Die ausstellende Region wird ge&auml;ndert von"; break;
case "La nazione di rilascio del documento verrà cambiata da":          $messaggio = "Die ausstellende Nation wird ge&auml;ndert"; break;
case "La <b>cittadinanza</b> verrà cancellata":                         $messaggio = "Die <b>Nationalit&auml;t</b> wird gel&ouml;scht"; break;
case "La <b>nazione di nascita</b> verrà cancellata":                   $messaggio = "Das <b>Geburtsland</b> wird gel&ouml;scht"; break;
case "La <b>regione di nascita</b> verrà cancellata":                   $messaggio = "Die <b>Geburtsregion</b> wird gel&ouml;scht"; break;
case "La <b>città di nascita</b> verrà cancellata":                    $messaggio = "Der <b>Geburtsort</b> wird gel&ouml;scht"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":     $messaggio = "Die <b>ausstellende Stadt</b> wird gel&ouml;scht"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata": $messaggio = "Die <b>ausstellende Region</b> wird gel&ouml;scht"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":    $messaggio = "Das <b>ausstellende Land</b> wird gel&ouml;scht"; break;
case "Codice fiscale":                                                   $messaggio = "Steuernummer"; break;
case "Il codice fiscale verrà cambiato da":                             $messaggio = "Die Steuernummer wird ge&auml;ndert von"; break;
case "Il <b>codice fiscale</b> verrà cancellato":                       $messaggio = "Die <b>Steuernummer</b> wird gel&ouml;scht"; break;
case "Titolo":                                                           $messaggio = "Titel"; break;
case "Il titolo verrà cambiato da":                                     $messaggio = "Der Titel wird gel&ouml;scht von"; break;
case "Il <b>titolo</b> verrà cancellato":                               $messaggio = "Der <b>Titel</b> wird gel&ouml;scht"; break;
case "Partita iva":                                                      $messaggio = "USt.Id."; break;
case "La partita iva verrà cambiata da":                                $messaggio = "Die Umsatzsteuernummer wird ge&auml;ndert von"; break;
case "La <b>partita iva</b> verrà cancellata":                          $messaggio = "Die<b>Umsatzsteuernummer</b> wird gel&ouml;scht"; break;
case "data inserimento":                                                 $messaggio = "Erstellungsdatum"; break;
case "carte di credito":                                                 $messaggio = "Kreditkarte"; break;
case "password per la visualizzazione delle carte di credito":           $messaggio = "Passwort f&uuml;r Kreditkartenansicht"; break;
case "invia":                                                            $messaggio = "senden"; break;
case "password errata":                                                  $messaggio = "falsches Kennwort"; break;
case "i dati della carta di credito sono stati cancellati":              $messaggio = "Kreditkartendaten wurden gel&ouml;scht"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":   $messaggio = "Kreditkartennummer ist <span class=\"colred\">falsch</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":         $messaggio = "CVC Nummer ist <span class=\"colred\">falsch</span>"; break;
case "i dati della carta di credito sono stati inseriti":                $messaggio = "Kreditkartendaten wurden eingef&uuml;gt"; break;
case "carta di credito del cliente":                                     $messaggio = "Kreditkarte des Kunden"; break;
case "CVC":                                                              $messaggio = "CVC"; break;
case "modifica i dati della carta di credito":                           $messaggio = "Kreditkartendaten &auml;ndern"; break;
case "cancella questa carta di credito":                                 $messaggio = "Diese Kreditkarte l&ouml;schen"; break;
case "soprannome":                                                       $messaggio = "Spitzname"; break;
case "Il soprannome verrà cambiato da":                                 $messaggio = "Der Spitzname wird ge&auml;ndert von"; break;
case "Il <b>soprannome</b> verrà cancellato":                           $messaggio = "Der <b>Spitzname</b> wird ge&ouml;scht"; break;
case "Lingua":  				                         $messaggio = "Sprache"; break;
case "La lingua verrà cambiata da":                                     $messaggio = "Die Sprache wird ge&auml;ndert von"; break;
case "La <b>lingua</b> verrà cancellata":                               $messaggio = "Die <b>Sprache</b> wird gel&ouml;scht"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>